# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .batch_test_response import BatchTestResponse

__all__ = ["TestListBatchTestsResponse"]

TestListBatchTestsResponse: TypeAlias = List[BatchTestResponse]
