# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .test_case_job_response import TestCaseJobResponse

__all__ = ["TestListTestRunsResponse"]

TestListTestRunsResponse: TypeAlias = List[TestCaseJobResponse]
