# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .test_case_definition_response import TestCaseDefinitionResponse

__all__ = ["TestListTestCaseDefinitionsResponse"]

TestListTestCaseDefinitionsResponse: TypeAlias = List[TestCaseDefinitionResponse]
